classdef instr_VTx < handle
    % INSTR_VTx Provides essential functions for setting up and controling the instrument
    
       properties
            instrID = '';   % VISA instrument ID (eg. 'rto-400101')
            connected = 0;  % Intsrument connected (0/1)
       end
       properties (Hidden)
            connection; 
       end
       methods
       % methods, including the constructor are defined in this block
           %Constructor
           function obj = instr_VTx(VxiID)
                obj.instrID = VxiID;             
           end
           

        function obj = Connect(obj)
       %   CONNECT Establish the connection to the device
            try
            disp('Connecting to VTx...');
            obj.connection = visa('ni',obj.instrID);
            %set(obj.connection, 'OutputBufferSize',32768);
            set(obj.connection, 'EOIMode','on');   
            set(obj.connection, 'EOSMode','write'); 
            fopen(obj.connection);                
            obj.connected = 1;
            catch err
                msgbox(err.message);
                obj.connected = 0;
            end
       end

        function Disconnect(obj)
            %   CONNECT Disconnect from the device
            fclose(obj.connection);
            delete(obj.connection);
            obj.connected = 0;
        end  
           
       function [val, cnt] = measureHdmi(obj)
           %    MEASUREHDMI Take the hdmi delay measurement. Returns [0,0]
           %    if no measurement could be taken
           %    val         Measured HDMI delay
           %    cnt         Device answer to 'READ:AVDA:TTV:COUN?'
            stat = obj.writeRead('READ:AVDA:TTV:STAT?');      
            if round(str2double(stat))
                cnt = obj.writeRead('READ:AVDA:TTV:COUN?');
                tmp = obj.writeRead('READ:AVDA:TTV:VAL?');    
                val = str2double(tmp);
            else
                warning('Video Analyzer not ready. HDMI delay not measured');
                cnt = 0;
                val = 0;
            end
       end
       
       function ConfigureForMiracast(obj)
           %    CONFIGUREFORMIRACAST Configures the instrument for the
           %    Miracast measurement
           disp('Configuring VTx...');
           fprintf(obj.connection, 'CONF:AVDA:TTV:APL:HYST 5'); 
           for ii = 1:10
               ret = round(str2double(obj.writeRead('*OPC?')));
                if ret;
                    break;
                else
                    pause(1);
                end
           end
           if ~ret
               warning('VTE could not be configured');
           end
           stat = obj.writeRead('INIT:AVDA;*OPC?');   
           
       end

       function ret = writeRead(obj,msg)
           % WRITEREAD writes a scpi command to the device and queries the
           % answer
            fprintf(obj.connection,msg);                
            ret = fscanf(obj.connection);
       end
           
       end       
end 